const readline = require('readline');
const rl = readline.createInterface({
    input: process.stdin,
    output: process.stdout
});

const { exec: __exec } = require('child_process');
function exec (cmd) {
    return new Promise((resolve, reject) => {
        __exec(cmd, (err, stdout, stderr) => {
            if (err) return reject(err);
            if (stderr) return reject(stderr);
            resolve(stdout);
        });
    });
}

(async () => {
    let package_manager;
    try {
        await exec('yarn -v');
        package_manager = 'yarn';
    } catch {
        package_manager = 'npm';
    }

    // Search nodemon in yarn globals
    let have_nodemon = false;
    if (package_manager === '-yarn') {
        const r = await exec('yarn global list --depth=0');
        if (r.indexOf('nodemon') !== -1) have_nodemon = true;
    }

    // And also search in npm globals
    if (!have_nodemon) {
        const r = await exec('npm list -g --depth=0');
        if (r.indexOf('nodemon') !== -1) have_nodemon = true;
    }

    if (!have_nodemon) {
        (function install_nodemon_question () {
            rl.question('`nodemon` required for development. Install this?\nG - install globally, L - locally, N - do not install\n> ', async answer => {
                switch (answer.toUpperCase()) {
                    case 'G':
                        if (package_manager === 'yarn') await exec('yarn global add nodemon');
                        else if (package_manager === 'npm') await exec('nppm i -g nodemon');
                        break;
                    case 'L':
                        if (package_manager === 'yarn') await exec('yarn add -D nodemon');
                        else if (package_manager === 'npm') await exec('npm i -D nodemon');
                        break;
                    case 'N': break;
                    default: install_nodemon_question();
                }

                console.log(process.cwd());
            });
        })();
    }
})();

try {
    require('nodemon');
} catch {
    // console.log(process.env);
}